import axios from 'axios';
import qs from 'query-string';
import { ListParams } from '@/api/list';

export interface DeptRecord {
  id?: number | undefined;
  parentId?: number;
  name: string;
  code: string;
  deptSort: number;
  remark: string;
  children?: DeptRecord[];
}

export function create(data: DeptRecord) {
  return axios.post(`/api/dept`, data);
}

export function update(data: DeptRecord) {
  return axios.patch(`/api/dept/${data.id}`, data);
}

export function remove(id: number) {
  return axios.delete(`/api/dept/${id}`);
}

export function getDeptTree(params?: Partial<DeptRecord>) {
  return axios.get<DeptRecord[]>(`/api/dept/trees`, {
    params,
    paramsSerializer: (obj) => {
      return qs.stringify(obj);
    },
  });
}
export function listDepts(params?: ListParams<Partial<DeptRecord>>) {
  return axios.get<DeptRecord[]>(`/api/dept`, {
    params,
    paramsSerializer: (obj) => {
      return qs.stringify(obj);
    },
  });
}
// export function queryDepts(params?: ListParams<Partial<DeptRecord>>) {
//   return queryList(`/api/dept`, params);
// }
